==> jackrabbit-oak-1.4.26-src.zip: jackrabbit-oak-1.4.26/oak-solr-core/src/main/java/org/apache/jackrabbit/oak/plugins/index/solr/configuration/SolrServerConfigurationProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jackrabbit.oak.plugins.index.solr.configuration;

import javax.annotation.Nonnull;

import org.apache.jackrabbit.oak.plugins.index.solr.server.SolrServerProvider;

/**
 * {@link org.apache.solr.client.solrj.SolrServer} configuration provider.
 */
public interface SolrServerConfigurationProvider<S extends SolrServerProvider> {

    /**
     * Provide a {@link SolrServerConfiguration} to be used to initialize a specific
     * {@link org.apache.solr.client.solrj.SolrServer} implementation.
     *
     * @return the {@link org.apache.jackrabbit.oak.plugins.index.solr.configuration.SolrServerConfiguration} holding the configuration parameters
     */
    @Nonnull
    SolrServerConfiguration<S> getSolrServerConfiguration();
}

==> jackrabbit-oak-1.6.23-src.zip: jackrabbit-oak-1.6.23/oak-solr-core/src/main/java/org/apache/jackrabbit/oak/plugins/index/solr/configuration/SolrServerConfigurationProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jackrabbit.oak.plugins.index.solr.configuration;

import javax.annotation.Nonnull;

import org.apache.jackrabbit.oak.plugins.index.solr.server.SolrServerProvider;

/**
 * {@link org.apache.solr.client.solrj.SolrClient} configuration provider.
 */
public interface SolrServerConfigurationProvider<S extends SolrServerProvider> {

    /**
     * Provide a {@link SolrServerConfiguration} to be used to initialize a specific
     * {@link org.apache.solr.client.solrj.SolrClient} implementation.
     *
     * @return the {@link org.apache.jackrabbit.oak.plugins.index.solr.configuration.SolrServerConfiguration} holding the configuration parameters
     */
    @Nonnull
    SolrServerConfiguration<S> getSolrServerConfiguration();
}
